@@ -72,11 +72,20 @@ def _get_factory_by_name() -> typing.Dict[
         "Kaisei Tokumin": default,
         "Kiwi Maru": default,
         "Klee One": default,
+        "Kosugi": default,
+        "Kosugi Maru": default,
+        "Mochiy Pop One": default,
+        "Mochiy Pop P One": default,
         "MotoyaLCedar": allow_monospace_ascii,
         "MotoyaLMaru": allow_monospace_ascii,
+        "M PLUS 1": default,
+        "M PLUS 1 Code": default,
+        "M PLUS 2": default,
         "Mplus 1p": default,
         "Mplus 1p Bold": default,
+        "Murecho": default,
         "Otomanopee One": has_no_pairs,
+        "Rock 3D": default,
         "Rounded Mplus 1c": default,
         "Rounded Mplus 1c Bold": default,
         "New Tegomin": default,
@@ -87,12 +96,27 @@ def _get_factory_by_name() -> typing.Dict[
         "RocknRoll One": default,
         "Sawarabi Gothic": default,
         "Sawarabi Mincho": default,
+        "Shippori Antique": default,
+        "Shippori Antique B1": default,
         "Shippori Mincho": default,
         "Shippori Mincho B1": default,
+        "Shizuru": default,
         "Stick": default,
         "Train One": default,
         "Yomogi": allow_monospace_ascii_no_vert,
+        "Yuji Boku": default,
+        "Yuji Hentaigana Akari": default,
+        "Yuji Hentaigana Akebono": default,
+        "Yuji Mai": default,
+        "Yuji Syuku": default,
         "Yusei Magic": has_no_vert_pairs,
+        "Zen Antique": default,
+        "Zen Antique Soft": default,
+        "Zen Kaku Gothic Antique": default,
+        "Zen Kaku Gothic New": default,
+        "Zen Kurenaido": default,
+        "Zen Maru Gothic": default,
+        "Zen Old Mincho": default,
         # KOR
         "Black And White Picture": has_no_pairs,
         "Black Han Sans": has_no_pairs,
